@@ -20,11 +20,6 @@
 
 __metaclass__ = type
 
-try:
-    from cStringIO import OutputType
-except ImportError:
-    from StringIO import StringIO as OutputType
-
 import genshi.core
 from genshi.template import NewTextTemplate, MarkupTemplate
 
@@ -46,12 +41,5 @@ class RelatorioStream(genshi.core.Stream):
         "Support for the bitwise operator"
         return RelatorioStream(self.events | function, self.serializer)
 
-    def __str__(self):
-        val = self.render()
-        if isinstance(val, OutputType):
-            return val.getvalue()
-        else:
-            return val
-
 MIMETemplateLoader.add_factory('text', NewTextTemplate)
 MIMETemplateLoader.add_factory('xml', MarkupTemplate)
