@@ -1,5 +1,6 @@
 ###############################################################################
 #
+# Copyright (c) 2014 Cedric Krier.
 # Copyright (c) 2007, 2008 OpenHex SPRL. (http://openhex.com) All Rights
 # Reserved.
 #
@@ -20,10 +21,7 @@
 
 __metaclass__ = type
 
-try:
-    from cStringIO import StringIO
-except ImportError:
-    from StringIO import StringIO
+from io import BytesIO
 
 import yaml
 import genshi
@@ -67,8 +65,8 @@ class CairoSerializer:
         self.text_serializer = genshi.output.TextSerializer()
 
     def __call__(self, stream):
-        result = StringIO()
-        yml = StringIO(_encode(self.text_serializer(stream)))
+        result = BytesIO()
+        yml = BytesIO(_encode(self.text_serializer(stream)))
         chart_yaml = yaml.load(yml.read())
         chart_info = chart_yaml['chart']
         chart_type = chart_info['output_type']
