@@ -59,12 +59,20 @@ except ImportError:
 
 GENSHI_EXPR = re.compile(r'''
         (/)?                                 # is this a closing tag?
-        (for|if|choose|when|otherwise|with)  # tag directive
+        (for|if|choose|when|otherwise|with|
+         attrs|content|replace|strip)        # tag directive
         \s*
-        (?:\s(\w+)=["'](.*)["']|$)           # match a single attr & its value
+        (?:\s([\w:-]+)=["'](.*)["']|$)       # match a single attr & its value
         |
         .*                                   # or anything else
         ''', re.VERBOSE)
+GENSHI_CLOSING_DIRECTIVE = ['for',
+                            'if',
+                            'choose',
+                            'when',
+                            'otherwise',
+                            'with',
+                            ]
 
 EXTENSIONS = {'image/png': 'png',
               'image/jpeg': 'jpg',
@@ -74,7 +82,7 @@ EXTENSIONS = {'image/png': 'png',
               'image/xbm': 'xbm',
              }
 
-RELATORIO_URI = 'http://relatorio.openhex.org/'
+RELATORIO_URI = 'relatorio'
 GENSHI_URI = 'http://genshi.edgewall.org/'
 MANIFEST = 'META-INF/manifest.xml'
 META = 'meta.xml'
@@ -147,8 +155,9 @@ class ImageDimension:
     def __call__(self, expr, width, height):
         # expr could be (bitstream, mimetype)
         # or (bitstreamm mimetype, width, height)
-        if len(expr) == 4:
-            width, height = expr[2:]
+        if len(expr) >= 4:
+            width, height = (
+                i or j for i, j in zip(expr[2:4], [width, height]))
         attrs = {}
         if width:
             attrs['{%s}width' % self.namespaces['svg']] = width
@@ -375,7 +384,7 @@ class Template(MarkupTemplate):
                                 % opened_tags[-1].text
                 warnings.warn(warn_msg)
 
-            if directive is not None:
+            if directive in GENSHI_CLOSING_DIRECTIVE:
                 # map closing tags with their opening tag
                 if is_opening:
                     opened_tags.append(statement)
@@ -410,7 +419,7 @@ class Template(MarkupTemplate):
             expr, directive, attr, a_val = parsed
 
             # If the node is a genshi directive statement:
-            if directive is not None:
+            if directive in GENSHI_CLOSING_DIRECTIVE:
                 opening = r_node
                 closing = closing_tags[id(r_node)]
 
@@ -462,6 +471,21 @@ class Template(MarkupTemplate):
                 # - we delete the closing statement (and its ancestors)
                 wrap_nodes_between(outermost_o_ancestor, outermost_c_ancestor,
                                    genshi_node)
+            elif directive:
+                # find the first parent with the same tag name as the attribute
+                parent = r_node
+                namespace, name = attr.split(':')
+                attr = '{%s}%s' % (self.namespaces[namespace], name)
+                while parent is not None and parent.tag != attr:
+                    parent = parent.getparent()
+                assert parent is not None, "Parent not found"
+
+                # add the py:attribute to the parent
+                py_attr = '{%s}%s' % (GENSHI_URI, directive)
+                parent.attrib[py_attr] = a_val
+
+                # remove the directive node
+                r_node.getparent().remove(r_node)
             else:
                 # It's not a genshi statement it's a python expression
                 parent = r_node.getparent().getparent()
@@ -662,6 +686,7 @@ class Template(MarkupTemplate):
         draw_name = '{%s}name' % draw_namespace
         draw_image = '{%s}image' % draw_namespace
         py_attrs = '{%s}attrs' % self.namespaces['py']
+        end_cell_address = '{%s}end-cell-address' % self.namespaces['table']
         svg_namespace = self.namespaces['svg']
         svg_width = '{%s}width' % svg_namespace
         svg_height = '{%s}height' % svg_namespace
@@ -669,7 +694,6 @@ class Template(MarkupTemplate):
         for draw in tree.xpath(xpath_expr, namespaces=self.namespaces):
             cache_id = id(draw)
             d_name = draw.attrib[draw_name][6:].strip()
-            draw.attrib[draw_name] = ''  # clean template code
             attr_expr = ("__relatorio_make_href(__relatorio_get_cache(%s))" %
                          cache_id)
             image_node = EtreeElement(draw_image,
@@ -683,6 +707,11 @@ class Template(MarkupTemplate):
                          "__relatorio_store_cache(%s, %s), '%s', '%s')" %
                          (cache_id, d_name, width, height))
             draw.attrib[py_attrs] = attr_expr
+            draw.attrib.pop(draw_name)
+            dico = "{'%s': (__relatorio_get_cache(%s)[4:5] or [''])[0]}"
+            update_py_attrs(draw, dico % (draw_name, cache_id))
+            # remove end-cell-address as the address specified could be wrong
+            draw.attrib.pop(end_cell_address, '')
 
     def _handle_innerdocs(self, tree):
         "finds inner_docs and adds them to the processing stack."
